@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -237,7 +237,8 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeAgentDealsByCache(self, request):
-        """供代理商拉取缓存的全量预付费客户订单
+        """供代理商拉取全量预付费普通客户订单
+        （对应控制台：客户订单-预付费-普通订单）
 
         :param request: Request instance for DescribeAgentDealsByCache.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsByCacheRequest`
@@ -259,6 +260,29 @@ class PartnersClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAgentDealsPriceDetailByDealName(self, request):
+        """供代理商使用名下有效普通代客的预付费子订单号查询订单费用详情
+
+        :param request: Request instance for DescribeAgentDealsPriceDetailByDealName.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsPriceDetailByDealNameRequest`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsPriceDetailByDealNameResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAgentDealsPriceDetailByDealName", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAgentDealsPriceDetailByDealNameResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAgentPayDealsV2(self, request):
         """可以查询代理商代付的预付费订单
 
