@@ -332,6 +332,9 @@ RESOURCENOTFOUND_BROKERCLUSTER = 'ResourceNotFound.BrokerCluster'
 # 集群不存在。
 RESOURCENOTFOUND_CLUSTER = 'ResourceNotFound.Cluster'
 
+# 链路不存在
+RESOURCENOTFOUND_DISASTERREPLICATELINK = 'ResourceNotFound.DisasterReplicateLink'
+
 # 环境不存在。
 RESOURCENOTFOUND_ENVIRONMENT = 'ResourceNotFound.Environment'
 
